@@ -14,12 +14,10 @@
 
 #include <memory>
 
-#include <KSaneCore>
+#include <Interface>
 
 class DevicesModelPrivate;
 
-using namespace KSaneIface;
-
 class DevicesModel : public QAbstractListModel
 {
     Q_OBJECT
@@ -41,7 +39,7 @@ public:
 
     Q_INVOKABLE QString getSelectedDeviceName() const;
 
-    void updateDevicesList(QList<KSaneCore::DeviceInfo> deviceList);
+    void updateDevicesList(const QList<KSaneCore::DeviceInformation *> &deviceList);
 
 public Q_SLOTS:
 
@@ -55,6 +53,6 @@ private:
     std::unique_ptr<DevicesModelPrivate> d;
 };
 
-QDebug operator<<(QDebug d, const KSaneCore::DeviceInfo &deviceInfo);
+QDebug operator<<(QDebug d, KSaneCore::DeviceInformation *deviceInfo);
 
 #endif // DEVICES_MODEL_H
